==> aliyun-java-sdk-ecs-2.2.1-sources.jar: com/aliyuncs/ecs/transform/v20140526/EipNotifyPaidResponseUnmarshaller.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.aliyuncs.ecs.transform.v20140526;

import com.aliyuncs.ecs.model.v20140526.EipNotifyPaidResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class EipNotifyPaidResponseUnmarshaller {

	public static EipNotifyPaidResponse unmarshall(EipNotifyPaidResponse eipNotifyPaidResponse, UnmarshallerContext context) {
		
		eipNotifyPaidResponse.setrequestId(context.stringValue("EipNotifyPaidResponse.requestId"));
		eipNotifyPaidResponse.setdata(context.stringValue("EipNotifyPaidResponse.data"));
		eipNotifyPaidResponse.setcode(context.stringValue("EipNotifyPaidResponse.code"));
		eipNotifyPaidResponse.setmessage(context.stringValue("EipNotifyPaidResponse.message"));
		eipNotifyPaidResponse.setsuccess(context.booleanValue("EipNotifyPaidResponse.success"));
	 
	 	return eipNotifyPaidResponse;
	}
}

==> aliyun-java-sdk-ecs-4.2.0-sources.jar: com/aliyuncs/ecs/transform/v20140526/EipNotifyPaidResponseUnmarshaller.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.aliyuncs.ecs.transform.v20140526;

import com.aliyuncs.ecs.model.v20140526.EipNotifyPaidResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class EipNotifyPaidResponseUnmarshaller {

	public static EipNotifyPaidResponse unmarshall(EipNotifyPaidResponse eipNotifyPaidResponse, UnmarshallerContext context) {
		
		eipNotifyPaidResponse.setRequestId(context.stringValue("EipNotifyPaidResponse.requestId"));
		eipNotifyPaidResponse.setData(context.stringValue("EipNotifyPaidResponse.data"));
		eipNotifyPaidResponse.setCode(context.stringValue("EipNotifyPaidResponse.code"));
		eipNotifyPaidResponse.setMessage(context.stringValue("EipNotifyPaidResponse.message"));
		eipNotifyPaidResponse.setSuccess(context.booleanValue("EipNotifyPaidResponse.success"));
	 
	 	return eipNotifyPaidResponse;
	}
}
